@@ -26,6 +26,7 @@ struct appres_struct {
   String geometry;
   Boolean debug;
   Boolean xtest;
+  Boolean always_on_top;
   Boolean jump_pointer;
   Boolean jump_pointer_always;
   Boolean quick_modifiers;
@@ -35,6 +36,9 @@ struct appres_struct {
   Boolean num_lock_state;
   Boolean auto_repeat;
   Boolean modal_keytop;
+  Boolean minimizable;
+  Boolean secure;
+  Boolean nonexitable;
   int modal_threshold;
   Boolean keypad;
   Boolean function_key;
@@ -74,6 +78,7 @@ struct appres_struct {
   String altgr_key_labels;
   String shift_altgr_key_labels;
   String deadkeys;
+  int altgr_keycode;
 
   String key_file;
   String dict_file;
